@@ -140,6 +140,7 @@ class ChattyAssetModel(TimestampValidationMixin, UpdateableMixin, BaseModel):
         **kwargs
     ) -> Dict[str, Any]:
         # Just add serializer to kwargs and let parent handle the JSON conversion
+        ordered_data = {}
         dumped_json = super().model_dump_json(*args, exclude=self.exclude_fields.get(serializer, set()), **kwargs)
         loaded_json = json.loads(dumped_json)
         if serializer == SerializerType.FRONTEND or serializer == SerializerType.FRONTEND_ASSET_PREVIEW:
@@ -154,7 +155,9 @@ class ChattyAssetModel(TimestampValidationMixin, UpdateableMixin, BaseModel):
             loaded_json["updated_at"] = datetime.fromisoformat(loaded_json["updated_at"])
             loaded_json["deleted_at"] = datetime.fromisoformat(loaded_json["deleted_at"]) if loaded_json["deleted_at"] else None
 
-        return loaded_json
+        ordered_data["name"] = loaded_json.pop("name", None)
+        ordered_data.update(loaded_json)
+        return ordered_data
 
 class CompanyAssetModel(ChattyAssetModel):
     company_id: StrObjectId = Field(frozen=True)
