@@ -343,8 +343,8 @@ class Chat(CompanyAssetModel):
         serializer = kwargs.get('serializer', SerializerType.API)
         if serializer == SerializerType.DATABASE:
             dump["last_message_timestamp"]= self.last_message_timestamp
-            dump["free_conversation_time_left_seconds"] = self.time_left_for_free_conversation
-            dump["free_template_window_time_left_seconds"] = self.time_left_for_free_template_window
+            dump["free_conversation_expire_date"] = self.free_conversation_expire_date
+            dump["free_template_window_expire_date"] = self.free_template_window_expire_date
             dump["last_message"] = self.last_message.model_dump_json(serializer=SerializerType.DATABASE) if self.last_message else None
             dump["flow_states"] = [flow_state.model_dump_json(serializer=SerializerType.DATABASE) for flow_state in self.flow_states]
         return dump
