@@ -160,7 +160,9 @@ class ChatService:
             ChatService.add_central_notification_from_text(chat=chat, body=f"Etiqueta {tag.name} eliminada del chat {chat.id} por {execution_context.executor.name}", subtype=MessageSubtype.TAG_DELETED)
             return assigned_asset_to_remove
         except StopIteration:
-            raise NotFoundError(message=f"Tag with id {tag_id} not found in chat {chat.id}")
+            logger.info(f"Tag with id {tag_id} not found in chat {chat.id}")
+            raise AlreadyCompleted(message=f"Tag with id {tag_id} not found in chat {chat.id}. Returning success")
+
 
     @staticmethod
     def add_chatty_ai_agent(chat : Chat, execution_context: ExecutionContext, chatty_ai_agent: ChattyAIAgent, mode_for_chat: Optional[ChattyAIMode] = None) -> AssignedAssetToChat:
@@ -416,7 +418,7 @@ class ChatService:
         """
         message = chat.get_message_by_id(message_id)
         if message is None:
-            logger.warning(f"Message with id {message_id} not found in chat {chat.id}")
+            # logger.warning(f"Message with id {message_id} not found in chat {chat.id}")
             raise NotFoundError(message=f"Message with id {message_id} not found in chat {chat.id}")
 
         message.update_status(new_status=status, status_datetime=datetime.now())
