@@ -100,6 +100,7 @@ class EventFactory:
             data=highlight_data,
             source="chatty_api.webapp",
             company_id=company_info.id,
+            frozen_company_name=company_info.frozen_name,
             trace_id=trace_id
         )
         events.append(event)
@@ -129,6 +130,7 @@ class EventFactory:
             data=ai_agent_data,
             source="chatty_api.webapp",
             company_id=company_info.id,
+            frozen_company_name=company_info.frozen_name,
             trace_id=trace_id
         )
         events.append(event)
@@ -158,6 +160,7 @@ class EventFactory:
             data=tag_data,
             source="chatty_api.webapp",
             company_id=company_info.id,
+            frozen_company_name=company_info.frozen_name,
             trace_id=trace_id
         )
         events.append(event)
@@ -187,6 +190,7 @@ class EventFactory:
             data=product_data,
             source="chatty_api.webapp",
             company_id=company_info.id,
+            frozen_company_name=company_info.frozen_name,
             trace_id=trace_id
         )
         events.append(event)
@@ -215,7 +219,8 @@ class EventFactory:
             data=quality_data,
             source="chatty_api.webapp",
             company_id=company_info.id,
-            trace_id=trace_id
+            frozen_company_name=company_info.frozen_name,
+            trace_id=trace_id,
         )
         events.append(event)
         return events
@@ -248,6 +253,7 @@ class EventFactory:
             data=contact_point_data,
             source="chatty_api.webapp",
             company_id=company_info.id,
+            frozen_company_name=company_info.frozen_name,
             trace_id=trace_id
         )
         events.append(event)
@@ -278,6 +284,7 @@ class EventFactory:
             data=sale_data,
             source="chatty_api.webapp",
             company_id=company_info.id,
+            frozen_company_name=company_info.frozen_name,
             trace_id=trace_id
         )
         events.append(event)
@@ -307,6 +314,7 @@ class EventFactory:
             data=business_area_data,
             source="chatty_api.webapp",
             company_id=company_info.id,
+            frozen_company_name=company_info.frozen_name,
             trace_id=trace_id
         )
         events.append(event)
@@ -336,6 +344,7 @@ class EventFactory:
             data=funnel_data,
             source="chatty_api.webapp",
             company_id=company_info.id,
+            frozen_company_name=company_info.frozen_name,
             trace_id=trace_id
         )
         events.append(event)
@@ -366,6 +375,7 @@ class EventFactory:
             data=workflow_data,
             source="chatty_api.webapp",
             company_id=company_info.id,
+            frozen_company_name=company_info.frozen_name,
             trace_id=trace_id
         )
         events.append(event)
@@ -397,6 +407,7 @@ class EventFactory:
             data=chat_status_data,
             source="chatty_api.webapp",
             company_id=company_info.id,
+            frozen_company_name=company_info.frozen_name,
             trace_id=trace_id
         )
         events.append(event)
@@ -430,6 +441,7 @@ class EventFactory:
             data=chat_status_data,
             source="chatty_api.webapp",
             company_id=company_info.id,
+            frozen_company_name=company_info.frozen_name,
             trace_id=trace_id
         )
         events.append(event)
@@ -464,6 +476,7 @@ class EventFactory:
             data=message_data,
             source="chatty_api.webapp",
             company_id=company_info.id,
+            frozen_company_name=company_info.frozen_name,
             trace_id=trace_id
         )
         events.append(event)
@@ -492,6 +505,7 @@ class EventFactory:
             data=message_data,
             source="chatty_api.webapp",
             company_id=company_info.id,
+            frozen_company_name=company_info.frozen_name,
             trace_id=trace_id
         )
         events.append(event)
@@ -523,13 +537,14 @@ class EventFactory:
             data=continuous_conversation_data,
             source="chatty_api.webapp",
             company_id=company_info.id,
+            frozen_company_name=company_info.frozen_name,
             trace_id=trace_id
         )
         events.append(event)
         return events
 
     @staticmethod
-    def asset_events(company_id: StrObjectId, trace_id: str, executor_type: ExecutorType, executor_id: StrObjectId, asset: ChattyAssetModel, asset_type: CompanyAssetType, event_type: EventType, time: datetime) -> List[Event]:
+    def asset_events(company_id: StrObjectId, trace_id: str, executor_type: ExecutorType, executor_id: StrObjectId, asset: ChattyAssetModel, asset_type: CompanyAssetType, event_type: EventType, time: datetime, company_info: EmpresaModel) -> List[Event]:
         events = []
 
         asset_data = AssetData(
@@ -546,6 +561,7 @@ class EventFactory:
             data=asset_data,
             source="chatty_api.webapp",
             company_id=company_id,
+            frozen_company_name=company_info.frozen_name,
             trace_id=trace_id
         )
         events.append(event)
@@ -565,6 +581,7 @@ class EventFactory:
             data=company_data,
             source="chatty_api.webapp",
             company_id=empresa_model.id,
+            frozen_company_name=empresa_model.frozen_name,
             trace_id=trace_id
         )
         events.append(event)
@@ -593,6 +610,7 @@ class EventFactory:
             data=user_data,
             source="chatty_api.webapp",
             company_id=company_info.id,
+            frozen_company_name=company_info.frozen_name,
             trace_id=trace_id
         )
         events.append(event)
